"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreviousTile = exports.getNextTile = exports.getNextNavigatedTile = void 0;
exports.loadExpandedTileFeature = loadExpandedTileFeature;
exports.addAutoAddTileFeature = addAutoAddTileFeature;
exports.loadTitle = loadTitle;
exports.waitForElm = waitForElm;
exports.waitForElements = waitForElements;
const __1 = require("../");
const widget_components_1 = require("./widget.components");
const expanded_swiper_loader_1 = require("./components/expanded-tile-swiper/expanded-swiper.loader");
const products_swiper_1 = require("./components/expanded-tile-swiper/products.swiper");
const getNextNavigatedTile = (currentTile, enabledTiles, direction) => {
    const currentIndex = enabledTiles.findIndex((tile) => tile.getAttribute("data-id") === currentTile.id);
    if (direction === "previous") {
        const previousTile = (0, exports.getPreviousTile)(enabledTiles, currentIndex);
        if (!previousTile) {
            throw new Error("Failed to find previous tile");
        }
        return previousTile.getAttribute("data-id");
    }
    else if (direction === "next") {
        const nextTile = (0, exports.getNextTile)(enabledTiles, currentIndex);
        if (!nextTile) {
            throw new Error("Failed to find next tile");
        }
        return nextTile.getAttribute("data-id");
    }
    return null;
};
exports.getNextNavigatedTile = getNextNavigatedTile;
const getNextTile = (enabledTiles, currentIndex) => enabledTiles[currentIndex + 1];
exports.getNextTile = getNextTile;
const getPreviousTile = (enabledTiles, currentIndex) => enabledTiles[currentIndex - 1];
exports.getPreviousTile = getPreviousTile;
function loadExpandedTileFeature(sdk) {
    const widgetContainer = sdk.getStyleConfig();
    const { click_through_url } = widgetContainer;
    if (click_through_url === "[EXPAND]") {
        (0, widget_components_1.loadExpandSettingComponents)(sdk);
        (0, __1.registerTileExpandListener)(sdk, expanded_swiper_loader_1.onTileExpand);
        (0, __1.registerGenericEventListener)(sdk, __1.EVENT_EXPANDED_TILE_CLOSE, expanded_swiper_loader_1.onTileClosed);
        (0, __1.registerGenericEventListener)(sdk, __1.EVENT_TILE_EXPAND_RENDERED, expanded_swiper_loader_1.onTileRendered);
        (0, __1.registerShareMenuOpenedListener)(sdk, (sourceId) => (0, expanded_swiper_loader_1.reduceBackgroundControlsVisibility)(sdk, sourceId));
        (0, __1.registerShareMenuClosedListener)(sdk, (sourceId) => (0, expanded_swiper_loader_1.resetBackgroundControlsVisibility)(sdk, sourceId));
        (0, __1.registerProductsUpdatedListener)(sdk, products_swiper_1.loadProductsSwiper);
    }
    else if (click_through_url === "[ORIGINAL_URL]" || /^https?:\/\/.+/.test(click_through_url ?? "")) {
        (0, __1.registerDefaultClickEvents)(sdk);
    }
    else if (click_through_url === "[CUSTOM]") {
        alert("Custom URL integration Not implemented yet");
    }
}
function addAutoAddTileFeature(sdk) {
    const { auto_refresh } = sdk.getStyleConfig();
    if (Boolean(auto_refresh) === true) {
        sdk.enableAutoAddNewTiles();
    }
}
function loadTitle(sdk) {
    const widgetTitle = document.createElement("p");
    const widgetContainer = sdk.getWidgetContainer();
    const title = widgetContainer.title;
    if (title) {
        widgetTitle.innerHTML = title;
    }
}
function waitForElm(parent, targets, callback) {
    if (targets.every(it => !!parent.querySelector(it))) {
        callback(targets.map(it => parent.querySelector(it)));
    }
    const observer = new MutationObserver((_, observer) => {
        if (targets.every(it => !!parent.querySelector(it))) {
            observer.disconnect();
            callback(targets.map(it => parent.querySelector(it)));
        }
    });
    observer.observe(parent, {
        childList: true,
        subtree: true
    });
}
function waitForElements(parent, target, callback) {
    const elements = parent.querySelectorAll(target);
    if (elements.length > 0) {
        callback(elements);
    }
    const observer = new MutationObserver(() => {
        const newElements = parent.querySelectorAll(target);
        if (newElements.length > 0) {
            callback(newElements);
            observer.disconnect();
        }
    });
    observer.observe(parent, {
        childList: true,
        subtree: true
    });
}
//# sourceMappingURL=widget.features.js.map